aaa = r"""

::C:

::cd C:\Users\frank_yu\py



::C:\Users\Public\Python39\Scripts\jupyter-lab.exe

::lab_py10.bat



::C:\Users\frank_yu\AppData\Local\Google\Chrome\Application\chrome_proxy.exe  --profile-directory=Default --app-id=gmifgajiejkkbgfbegjkojkdeibadhdl


chcp 65001

D:  

::cd  "D:\Users\t4_kelly\OneDrive\私人文件，dengchunying1988\Documents\sb_py"


cd "D:\t3\OneDrive\私人文件，dengchunying1988\Documents\sb_py"

C:\anaconda3\Scripts\jupyter-lab.exe --no-browser

C:\Users\frank_yu\AppData\Local\Google\Chrome\Application\chrome_proxy.exe  --profile-directory=Default --app-id=gmifgajiejkkbgfbegjkojkdeibadhdl






"""

print(aaa)

input()